@@ -4,7 +4,7 @@
 # hashcash.pl - Wallet for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/hashcash.pl v1.119 Sun Jun 11 21:21:32 PDT 2017 $
+# $Id: bin/hashcash.pl v1.120 Tue Jun 13 02:59:50 PDT 2017 $
 
 use warnings;
 
@@ -23,6 +23,14 @@ use File::HomeDir;
 
 my $HASHCASH = $ENV{HASHCASHDIR} || File::HomeDir->my_home . '/.hashcash';
 
+unless (-d $HASHCASH) {
+  die "Directory $HASHCASH doesn't exist and couldn't be created.\n" unless mkdir($HASHCASH, 0700);
+}
+
+unless (-d "$HASHCASH/stash") {
+  die "Directory $HASHCASH/.stash doesn't exist and couldn't be created.\n" unless mkdir("$HASHCASH/stash", 0700);
+}
+
 # Get vault configs, default to first vault
 my @vaults = map { new Persistence::Object::Simple ('__Fn' => $_) } glob("$HASHCASH/vaults/*.cfg");
 my $vaultid = $vaults[0]->{id};
@@ -1043,8 +1051,8 @@ hashcash.pl - Wallet for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.119 $
- $Date: Sun Jun 11 21:21:32 PDT 2017 $
+ $Revision: 1.120 $
+ $Date: Tue Jun 13 02:59:50 PDT 2017 $
 
 =head1 SYNOPSIS
 
