@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 # -*-cperl-*-
 #
-# vault.pl - Vault server for HashCash digital cash
+# vault.pl - Vault server for HashCash Digital Cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/vault.pl v1.119 Sun Jun 11 21:21:32 PDT 2017 $
+# $Id: bin/vault.pl v1.120 Tue Jun 13 02:59:50 PDT 2017 $
 
 use strict;
 use warnings;
@@ -25,6 +25,14 @@ use Crypt::CBC;
 
 my $HASHCASH = $ENV{HASHCASHDIR} || File::HomeDir->my_home . '/.hashcash';
 
+unless (-d $HASHCASH) {
+  die "Directory $HASHCASH doesn't exist and couldn't be created.\n" unless mkdir($HASHCASH, 0700);
+}
+
+unless (-d "$HASHCASH/vaults") {
+  die "Directory $HASHCASH/.vaults doesn't exist and couldn't be created.\n" unless mkdir("$HASHCASH/vaults", 0700);
+}
+
 my $vault = new Crypt::HashCash::Vault::Bitcoin ( DB => "$HASHCASH/vault.db",
 						  KeyDB => "$HASHCASH/vaults/vault.key" );
 
@@ -81,12 +89,12 @@ __END__
 
 =head1 NAME
 
-vault.pl - Vault for HashCash digital cash
+vault.pl - Vault for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.119 $
- $Date: Sun Jun 11 21:21:32 PDT 2017 $
+ $Revision: 1.120 $
+ $Date: Tue Jun 13 02:59:50 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -100,24 +108,15 @@ and returns the responses.
 
 This command is primarily for testing. For real vaults, optimal
 security and performance can be achieved by running the vault on an
-offline cluster using B<vault-worker.pl> and B<vault-queuer.pl>
-instead,
+air-gapped cluster (see L<vault-worker.pl> and L<vault-queuer.pl>).
 
 =head1 COMMAND LINE OPTIONS
 
-=over
-
-=item B<--keygen>
-
-=back
-
-=over
+=head2 --keygen
 
 Create blind-signing keys for all coin denominations supported by the
 vault.
 
-=back
-
 =head1 SEE ALSO
 
 =head2 vault-worker.pl
