@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
-# Crypt::HashCash::Client - Client for HashCash digital cash
+# Crypt::HashCash::Client - Client for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Client.pm v1.119 Sun Jun 11 21:21:31 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Client.pm v1.120 Tue Jun 13 02:59:49 PDT 2017 $
 
 package Crypt::HashCash::Client;
 
@@ -23,7 +23,7 @@ use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.119 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.120 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -253,12 +253,12 @@ __END__
 
 =head1 NAME
 
-Crypt::HashCash::Client - Client for HashCash digital cash
+Crypt::HashCash::Client - Client for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.119 $
- $Date: Sun Jun 11 21:21:31 PDT 2017 $
+ $Revision: 1.120 $
+ $Date: Tue Jun 13 02:59:49 PDT 2017 $
 
 =head1 SYNOPSIS
 
