@@ -3,7 +3,7 @@
 # Crypt::HashCash::Coin - HashCash Digital Cash Coin
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Coin.pm v1.119 Sun Jun 11 21:21:31 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Coin.pm v1.120 Tue Jun 13 02:59:49 PDT 2017 $
 
 package Crypt::HashCash::Coin;
 
@@ -13,7 +13,7 @@ use strict;
 use Crypt::HashCash qw (_squish _unsquish _hex _dec);
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.119 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.120 $' =~ /\s+([\d\.]+)/;
 
 sub as_string {
   my $self = shift;
@@ -103,12 +103,12 @@ __END__
 
 =head1 NAME
 
-Crypt::HashCash::Coin - HashCash digital cash coin
+Crypt::HashCash::Coin - HashCash Digital Cash Coin
 
 =head1 VERSION
 
- $Revision: 1.119 $
- $Date: Sun Jun 11 21:21:31 PDT 2017 $
+ $Revision: 1.120 $
+ $Date: Tue Jun 13 02:59:49 PDT 2017 $
 
 =head1 SYNOPSIS
 
