@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
-# Crypt::HashCash::CoinRequest - HashCash digital cash coin request
+# Crypt::HashCash::CoinRequest - HashCash Digital Cash Coin Request
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/CoinRequest.pm v1.119 Sun Jun 11 21:21:31 PDT 2017 $
+# $Id: lib/Crypt/HashCash/CoinRequest.pm v1.120 Tue Jun 13 02:59:49 PDT 2017 $
 
 package Crypt::HashCash::CoinRequest;
 
@@ -14,7 +14,7 @@ use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.119 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.120 $' =~ /\s+([\d\.]+)/;
 
 sub from_string {
   my ($class, $str) = @_; $str =~ s/\s*$//;
@@ -58,12 +58,12 @@ __END__
 
 =head1 NAME
 
-Crypt::HashCash::CoinRequest - HashCash digital cash coin request
+Crypt::HashCash::CoinRequest - HashCash Digital Dash Doin Request
 
 =head1 VERSION
 
- $Revision: 1.119 $
- $Date: Sun Jun 11 21:21:31 PDT 2017 $
+ $Revision: 1.120 $
+ $Date: Tue Jun 13 02:59:49 PDT 2017 $
 
 =head1 SYNOPSIS
 
